==> streamtuner-0.11.1.tar.gz: streamtuner-0.11.1/src/streamtuner/st-stock.h <==
/*
 * $Id: st-stock.h,v 1.12 2004/01/27 14:16:42 jylefort Exp $
 *
 * Copyright (c) 2003, 2004 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _ST_STOCK_H
#define _ST_STOCK_H

#define ST_STOCK_TUNE_IN		"st-tune-in"
#define ST_STOCK_RECORD			"st-record"
#define ST_STOCK_BROWSE			"st-browse"

#define ST_STOCK_QUIT_WITHOUT_SAVING	"st-quit-without-saving"
#define ST_STOCK_SEARCH			"st-search"
#define ST_STOCK_OPEN_LINK		"st-open-link"
#define ST_STOCK_COPY_LINK_ADDRESS	"st-copy-link-address"

#define ST_STOCK_ADD_BOOKMARK		"st-add-bookmark"
#define ST_STOCK_REMOVE_BOOKMARK	"st-remove-bookmark"

#define ST_STOCK_BOOKMARKS		"st-bookmarks"
#define ST_STOCK_CATEGORY		"st-category"
#define ST_STOCK_CATEGORY_OPEN		"st-category-open"

void st_stock_init (void);

#endif /* _ST_STOCK_H */

==> streamtuner-0.12.2.tar.gz: streamtuner-0.12.2/src/streamtuner/st-stock.h <==
/*
 * $Id: st-stock.h,v 1.24 2004/03/24 16:34:06 jylefort Exp $
 *
 * Copyright (c) 2003, 2004 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _ST_STOCK_H
#define _ST_STOCK_H

#define ST_STOCK_TUNE_IN		"st-tune-in"
#define ST_STOCK_RECORD			"st-record"
#define ST_STOCK_BROWSE			"st-browse"

#define ST_STOCK_QUIT_WITHOUT_SAVING	"st-quit-without-saving"
#define ST_STOCK_SEARCH			"st-search"
#define ST_STOCK_OPEN_LINK		"st-open-link"
#define ST_STOCK_COPY_LINK_ADDRESS	"st-copy-link-address"

#define ST_STOCK_NEW_PRESELECTION	"st-new-preselection"
#define ST_STOCK_ADD_BOOKMARK		"st-add-bookmark"

#define ST_STOCK_CATEGORY		"st-category"
#define ST_STOCK_CATEGORY_OPEN		"st-category-open"

void st_stock_init (void);

#endif /* _ST_STOCK_H */
